==> qtjambi-qt3drender-debuginfo-macos-5.15.17.jar: sources/QtJambi3DRender/QBufferDataGenerator_shell.cpp <==
#include "QBufferDataGenerator_shell.h"
#include <QtJambi/Cast>

void deleter_Qt3DRender_QBufferDataGenerator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DRender::QBufferDataGenerator")
    Qt3DRender::QBufferDataGenerator *_ptr = reinterpret_cast<Qt3DRender::QBufferDataGenerator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QBufferDataGenerator_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QBufferDataGenerator_shell) ); }

jmethodID QBufferDataGenerator_shell::__shell_javaMethod(int pos) const { return QBufferDataGenerator_shell::__shell()->javaMethod(typeid(Qt3DRender::QBufferDataGenerator), pos); }

// emitting (writeShellConstructor)
QBufferDataGenerator_shell::QBufferDataGenerator_shell()
    : Qt3DRender::QBufferDataGenerator()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DRender::QBufferDataGenerator::QBufferDataGenerator_shell()", QBufferDataGenerator_shell::__shell())
    QBufferDataGenerator_shell::__shell()->constructed(typeid(Qt3DRender::QBufferDataGenerator));
}

// emitting (writeShellDestructor)
QBufferDataGenerator_shell::~QBufferDataGenerator_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DRender::QBufferDataGenerator::~Qt3DRender::QBufferDataGenerator()", QBufferDataGenerator_shell::__shell())
    QBufferDataGenerator_shell::__shell()->destructed(typeid(Qt3DRender::QBufferDataGenerator));
}

void QBufferDataGenerator_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QBufferDataGenerator_shell*>(ptr)->QBufferDataGenerator_shell::__shell()->tryDeleteShell(typeid(Qt3DRender::QBufferDataGenerator));
}

// emitting Virtual overrides (virtualFunctions)
qintptr QBufferDataGenerator_shell::id() const
{

    if(JniEnvironment __jni_env{200}) {
        if(jobject __qt_this = __shell()->getJavaObjectLocalRef(__jni_env)){
            return qintptr(QtJambiAPI::getJavaObjectHashCode(__jni_env, __jni_env->GetObjectClass(__qt_this)));
        }else{
            __shell()->warnForMethod("Qt3DRender::QAbstractFunctor::id() const");
        }
    }

    return 0;
}

QByteArray QBufferDataGenerator_shell::operator()()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("Qt3DRender::QBufferDataGenerator::", QBufferDataGenerator_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QByteArray  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QBufferDataGenerator_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QByteArray >(__jni_env, __java_return_value);
                } else {
                    QBufferDataGenerator_shell::__shell()->warnForMethod("Qt3DRender::QBufferDataGenerator::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "Qt3DRender::QBufferDataGenerator::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QByteArray();
        }
    }else{
        return QByteArray();
    }
}

bool QBufferDataGenerator_shell::operator==(const Qt3DRender::QBufferDataGenerator& other0) const
{
    if(jmethodID method_id = __shell_javaMethod(2)){
        QTJAMBI_JAVA_METHOD_CALL("Qt3DRender::QBufferDataGenerator::", QBufferDataGenerator_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QBufferDataGenerator_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_other0 = qtjambi_cast<jobject>(__jni_env, &other0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_other0);
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id, __java_other0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QBufferDataGenerator_shell::__shell()->warnForMethod("Qt3DRender::QBufferDataGenerator::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "Qt3DRender::QBufferDataGenerator::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return false;
        }
    }else{
        return false;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QBufferDataGenerator_access::__qt_invoke(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method Qt3DRender::QBufferDataGenerator::operator()()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method Qt3DRender::QBufferDataGenerator::operator()().";
    } else {
        QByteArray __qt_return_value = operator()();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

jboolean QBufferDataGenerator_access::__qt_equals_cref_Qt3DRender_QBufferDataGenerator_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const Qt3DRender::QBufferDataGenerator& __qt_other0 = QtJambiAPI::interfaceReferenceFromNativeId<Qt3DRender::QBufferDataGenerator>(__jni_env, other0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method Qt3DRender::QBufferDataGenerator::operator==(const Qt3DRender::QBufferDataGenerator & other) const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method Qt3DRender::QBufferDataGenerator::operator==(const Qt3DRender::QBufferDataGenerator & other) const.";
    } else {
        bool __qt_return_value = operator==(__qt_other0);
        return jboolean(__qt_return_value);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_Qt3DRender_QBufferDataGenerator_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    Qt3DRender::QBufferDataGenerator *__qt_this = new(__qtjambi_ptr) QBufferDataGenerator_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QBufferDataGenerator_shell
void __qt_destruct_Qt3DRender_QBufferDataGenerator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DRender::QBufferDataGenerator")
    reinterpret_cast<QBufferDataGenerator_shell*>(ptr)->~QBufferDataGenerator_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DRender::QBufferDataGenerator::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QBufferDataGenerator_00024Impl_initialize_1native__Lio_qt_qt3d_render_QBufferDataGenerator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DRender::QBufferDataGenerator::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DRender_QBufferDataGenerator_0, sizeof(QBufferDataGenerator_shell), typeid(Qt3DRender::QBufferDataGenerator), true, &deleter_Qt3DRender_QBufferDataGenerator, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DRender::QBufferDataGenerator::operator()()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QBufferDataGenerator_00024Impl_00024ConcreteWrapper_invoke_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Qt3DRender::QBufferDataGenerator *__qt_this = QtJambiAPI::interfaceFromNativeId<Qt3DRender::QBufferDataGenerator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QBufferDataGenerator::operator()()", __qt_this)
        __java_return_value = static_cast<QBufferDataGenerator_access*>(__qt_this)->__qt_invoke(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DRender::QBufferDataGenerator::operator==(Qt3DRender::QBufferDataGenerator)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QBufferDataGenerator_00024Impl_00024ConcreteWrapper_equals_1native_1cref_1Qt3DRender_1QBufferDataGenerator_1constfct__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DRender::QBufferDataGenerator *__qt_this = QtJambiAPI::interfaceFromNativeId<Qt3DRender::QBufferDataGenerator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QBufferDataGenerator::operator==(Qt3DRender::QBufferDataGenerator)const", __qt_this)
        __java_return_value = static_cast<const QBufferDataGenerator_access*>(__qt_this)->__qt_equals_cref_Qt3DRender_QBufferDataGenerator_constfct(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DRender_QBufferDataGenerator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<Qt3DRender::QBufferDataGenerator>("Qt3DRender::QBufferDataGenerator", "io/qt/qt3d/render/QBufferDataGenerator");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "invoke", "()Lio/qt/core/QByteArray;", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "equals", "(Lio/qt/qt3d/render/QBufferDataGenerator;)Z", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DRender_QBufferDataGenerator, {
        ConstructorInfo(&__qt_construct_Qt3DRender_QBufferDataGenerator_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DRender_QBufferDataGenerator);
    registerSizeOfShell(typeId, sizeof(QBufferDataGenerator_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(Qt3DRender::QBufferDataGenerator* _object = dynamic_cast<Qt3DRender::QBufferDataGenerator*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            Qt3DRender::QBufferDataGenerator *object = reinterpret_cast<Qt3DRender::QBufferDataGenerator *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const Qt3DRender::QBufferDataGenerator *object = reinterpret_cast<const Qt3DRender::QBufferDataGenerator *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
    registerPolymorphyHandler(typeid(Qt3DRender::QAbstractFunctor), typeId, [](void *ptr, qintptr& offset) -> bool {
            Qt3DRender::QAbstractFunctor *object = reinterpret_cast<Qt3DRender::QAbstractFunctor *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(Qt3DRender::QBufferDataGenerator* _object = dynamic_cast<Qt3DRender::QBufferDataGenerator*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids

    registerInterfaceOffset(typeId, typeid(Qt3DRender::QAbstractFunctor), int(reinterpret_cast<quintptr>(static_cast<Qt3DRender::QAbstractFunctor *>(reinterpret_cast<Qt3DRender::QBufferDataGenerator *>(0x10000000)))) - 0x10000000);

// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3drender-debuginfo-macos-5.15.20.jar: sources/QtJambi3DRender/QBufferDataGenerator_shell.cpp <==
#include "QBufferDataGenerator_shell.h"
#include <QtJambi/Cast>

void deleter_Qt3DRender_QBufferDataGenerator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DRender::QBufferDataGenerator")
    Qt3DRender::QBufferDataGenerator *_ptr = reinterpret_cast<Qt3DRender::QBufferDataGenerator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QBufferDataGenerator_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QBufferDataGenerator_shell) ); }

jmethodID QBufferDataGenerator_shell::__shell_javaMethod(int pos) const { return QBufferDataGenerator_shell::__shell()->javaMethod(typeid(Qt3DRender::QBufferDataGenerator), pos); }

// emitting (writeShellConstructor)
QBufferDataGenerator_shell::QBufferDataGenerator_shell()
    : Qt3DRender::QBufferDataGenerator()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DRender::QBufferDataGenerator::QBufferDataGenerator_shell()", QBufferDataGenerator_shell::__shell())
    QBufferDataGenerator_shell::__shell()->constructed(typeid(Qt3DRender::QBufferDataGenerator));
}

// emitting (writeShellDestructor)
QBufferDataGenerator_shell::~QBufferDataGenerator_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DRender::QBufferDataGenerator::~Qt3DRender::QBufferDataGenerator()", QBufferDataGenerator_shell::__shell())
    QBufferDataGenerator_shell::__shell()->destructed(typeid(Qt3DRender::QBufferDataGenerator));
}

void QBufferDataGenerator_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QBufferDataGenerator_shell*>(ptr)->QBufferDataGenerator_shell::__shell()->tryDeleteShell(typeid(Qt3DRender::QBufferDataGenerator));
}

// emitting Virtual overrides (virtualFunctions)
qintptr QBufferDataGenerator_shell::id() const
{

    if(JniEnvironment __jni_env{200}) {
        if(jobject __qt_this = __shell()->getJavaObjectLocalRef(__jni_env)){
            return qintptr(QtJambiAPI::getJavaObjectHashCode(__jni_env, __jni_env->GetObjectClass(__qt_this)));
        }else{
            __shell()->warnForMethod("Qt3DRender::QAbstractFunctor::id() const");
        }
    }

    return 0;
}

QByteArray QBufferDataGenerator_shell::operator()()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("Qt3DRender::QBufferDataGenerator::", QBufferDataGenerator_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QByteArray  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QBufferDataGenerator_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QByteArray >(__jni_env, __java_return_value);
                } else {
                    QBufferDataGenerator_shell::__shell()->warnForMethod("Qt3DRender::QBufferDataGenerator::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "Qt3DRender::QBufferDataGenerator::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QByteArray();
        }
    }else{
        return QByteArray();
    }
}

bool QBufferDataGenerator_shell::operator==(const Qt3DRender::QBufferDataGenerator& other0) const
{
    if(jmethodID method_id = __shell_javaMethod(2)){
        QTJAMBI_JAVA_METHOD_CALL("Qt3DRender::QBufferDataGenerator::", QBufferDataGenerator_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QBufferDataGenerator_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_other0 = qtjambi_cast<jobject>(__jni_env, &other0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_other0);
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id, __java_other0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QBufferDataGenerator_shell::__shell()->warnForMethod("Qt3DRender::QBufferDataGenerator::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "Qt3DRender::QBufferDataGenerator::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return false;
        }
    }else{
        return false;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QBufferDataGenerator_access::__qt_invoke(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method Qt3DRender::QBufferDataGenerator::operator()()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method Qt3DRender::QBufferDataGenerator::operator()().";
    } else {
        QByteArray __qt_return_value = operator()();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

jboolean QBufferDataGenerator_access::__qt_equals_cref_Qt3DRender_QBufferDataGenerator_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const Qt3DRender::QBufferDataGenerator& __qt_other0 = QtJambiAPI::interfaceReferenceFromNativeId<Qt3DRender::QBufferDataGenerator>(__jni_env, other0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method Qt3DRender::QBufferDataGenerator::operator==(const Qt3DRender::QBufferDataGenerator & other) const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method Qt3DRender::QBufferDataGenerator::operator==(const Qt3DRender::QBufferDataGenerator & other) const.";
    } else {
        bool __qt_return_value = operator==(__qt_other0);
        return jboolean(__qt_return_value);
    }
}

// emitting (writeConstructors)
// new QBufferDataGenerator()
void __qt_construct_Qt3DRender_QBufferDataGenerator(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBufferDataGenerator()")
    Q_UNUSED(__java_arguments)
    Qt3DRender::QBufferDataGenerator *__qt_this = new(__qtjambi_ptr) QBufferDataGenerator_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// Qt3DRender::QBufferDataGenerator::QBufferDataGenerator()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QBufferDataGenerator_00024Impl_initialize_1native__Lio_qt_qt3d_render_QBufferDataGenerator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DRender::QBufferDataGenerator::QBufferDataGenerator()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DRender_QBufferDataGenerator, sizeof(QBufferDataGenerator_shell), typeid(Qt3DRender::QBufferDataGenerator), true, &deleter_Qt3DRender_QBufferDataGenerator, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QBufferDataGenerator_shell
void __qt_destruct_Qt3DRender_QBufferDataGenerator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DRender::QBufferDataGenerator")
    reinterpret_cast<QBufferDataGenerator_shell*>(ptr)->~QBufferDataGenerator_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DRender::QBufferDataGenerator::operator()()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QBufferDataGenerator_00024Impl_00024ConcreteWrapper_invoke_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Qt3DRender::QBufferDataGenerator *__qt_this = QtJambiAPI::interfaceFromNativeId<Qt3DRender::QBufferDataGenerator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QBufferDataGenerator::operator()()", __qt_this)
        __java_return_value = static_cast<QBufferDataGenerator_access*>(__qt_this)->__qt_invoke(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DRender::QBufferDataGenerator::operator==(Qt3DRender::QBufferDataGenerator)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QBufferDataGenerator_00024Impl_00024ConcreteWrapper_equals_1native_1cref_1Qt3DRender_1QBufferDataGenerator_1constfct__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DRender::QBufferDataGenerator *__qt_this = QtJambiAPI::interfaceFromNativeId<Qt3DRender::QBufferDataGenerator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QBufferDataGenerator::operator==(Qt3DRender::QBufferDataGenerator)const", __qt_this)
        __java_return_value = static_cast<const QBufferDataGenerator_access*>(__qt_this)->__qt_equals_cref_Qt3DRender_QBufferDataGenerator_constfct(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DRender_QBufferDataGenerator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<Qt3DRender::QBufferDataGenerator>("Qt3DRender::QBufferDataGenerator", "io/qt/qt3d/render/QBufferDataGenerator");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "invoke", "()Lio/qt/core/QByteArray;", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "equals", "(Lio/qt/qt3d/render/QBufferDataGenerator;)Z", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DRender_QBufferDataGenerator, {
        ConstructorInfo(&__qt_construct_Qt3DRender_QBufferDataGenerator, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DRender_QBufferDataGenerator);
    registerSizeOfShell(typeId, sizeof(QBufferDataGenerator_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(Qt3DRender::QBufferDataGenerator* _object = dynamic_cast<Qt3DRender::QBufferDataGenerator*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            Qt3DRender::QBufferDataGenerator *object = reinterpret_cast<Qt3DRender::QBufferDataGenerator *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const Qt3DRender::QBufferDataGenerator *object = reinterpret_cast<const Qt3DRender::QBufferDataGenerator *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
    registerPolymorphyHandler(typeid(Qt3DRender::QAbstractFunctor), typeId, [](void *ptr, qintptr& offset) -> bool {
            Qt3DRender::QAbstractFunctor *object = reinterpret_cast<Qt3DRender::QAbstractFunctor *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(Qt3DRender::QBufferDataGenerator* _object = dynamic_cast<Qt3DRender::QBufferDataGenerator*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids

    registerInterfaceOffset(typeId, typeid(Qt3DRender::QAbstractFunctor), int(reinterpret_cast<quintptr>(static_cast<Qt3DRender::QAbstractFunctor *>(reinterpret_cast<Qt3DRender::QBufferDataGenerator *>(0x10000000)))) - 0x10000000);

// BEGIN: enums and flags
// END: enums and flags
}
